import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The bloodstream is the setting for our White Blood Cell scenario. 
 * It's a place where blood cells, battery and meteors float around.
 * 
 * @author Michael Kölling
 * @version 0.1
 */
public class Galaxy extends World
{
    private int score;
    private int time;
    /**
     * Constructor: Set up the staring objects.
     */
    public Galaxy()
    {    
        super(780, 360, 1); 

        prepare();

        setPaintOrder(SpaceBorder.class);
        score = 0;
        showScore();
        time = 2000;
        showTime();
    }

    private void showTime()
    {
        showText("Time: " + time, 690, 25);
    }

    private void countTime()
    {
        time--;
        showTime();
        if (time == 0)
        {
            showEndMessage();
            Greenfoot.stop();
        }
    }

    private void showEndMessage()
    {
        showText("Time is up - you win!", 390, 150);
        showText("Your final score: " + score + " points", 390, 170);
    }

    private void showScore()
    {
        showText("Score: " + score, 80, 25);
    }

    /**
     * Create new floating objects at irregular intervals.
     */
    public void act()
    {
        if (Greenfoot.getRandomNumber(100) < 3)
        {
            addObject(new Battery(), 779, Greenfoot.getRandomNumber(360));
        }
        if (Greenfoot.getRandomNumber(100) < 1)
        {
            addObject(new UpperStars(), 779, 359);
        }
        if (Greenfoot.getRandomNumber(100) < 1)
        {
            addObject(new UpperStars(), 779, 1);
        }
        if (Greenfoot.getRandomNumber(100) < 1)
        {
            addObject(new Meteor(), 779, Greenfoot.getRandomNumber(360));
        }
        if (Greenfoot.getRandomNumber(100) < 6)
        {
            addObject(new Star(), 779, Greenfoot.getRandomNumber(360));
        }
        
        countTime();
    }

    /**
     * Adds score to the game and will increase or decrease based on how game is played
     */
    public void addScore()
    {
        score = score + 20;
        showText("Score: " + score, 80, 25);

    }

    public void addScore(int points)
    {
        score = score + points;
        showText("Score: " + score, 80, 25);
        if (score < 0)
        {
            Greenfoot.playSound("endgame.wav");

            Greenfoot.stop();
        }
    }

    /**
     * Prepare the world for the start of the program. In this case: Create
     * a spaceship and the upperstars at the edge of the galaxy.
     */
    private void prepare()
    {
        Spaceship spaceship = new Spaceship();
        addObject(spaceship, 105, 179);
        UpperStars upperstars = new UpperStars();
        addObject(upperstars, 126, 1);
        UpperStars upperstars2 = new UpperStars();
        addObject(upperstars2, 342, 5);
        UpperStars upperstars3 = new UpperStars();
        addObject(upperstars3, 589, 2);
        UpperStars upperstars4 = new UpperStars();
        addObject(upperstars4, 695, 5);
        UpperStars upperstars5 = new UpperStars();
        addObject(upperstars5, 114, 359);
        UpperStars upperstars6 = new UpperStars();
        UpperStars upperstars7 = new UpperStars();
        addObject(upperstars7, 295, 353);
        UpperStars upperstars8 = new UpperStars();
        UpperStars upperstars9 = new UpperStars();
        UpperStars upperstars10 = new UpperStars();
        addObject(upperstars10, 480, 358);
        UpperStars upperstars11 = new UpperStars();
        addObject(upperstars11, 596, 359);
        UpperStars upperstars12 = new UpperStars();
        addObject(upperstars12, 740, 354);
        SpaceBorder spaceborder = new SpaceBorder();
        addObject(spaceborder, 0, 180);
        SpaceBorder spaceborder2 = new SpaceBorder();
        addObject(spaceborder2, 770, 180);

    }
}
